@@ -6,6 +6,8 @@ from concurrent.futures import CancelledError, TimeoutError
 from six.moves.queue import Empty
 from lxml import etree
 
+import six
+
 from netconf_client.error import RpcError
 from netconf_client.rpc import (
     edit_config,
@@ -24,6 +26,15 @@ from netconf_client.rpc import (
     delete_config,
 )
 
+if six.PY3:
+    from time import monotonic
+
+    _get_current_timestamp = monotonic
+else:
+    from time import time
+
+    _get_current_timestamp = time
+
 
 # Defines the scope for netconf traces
 _logger = logging.getLogger("netconf_client.manager")
@@ -210,14 +221,24 @@ class Manager:
         (raw, ele) = (None, None)
         self._log_rpc_request(rpc_xml)
 
+        current_timestamp = _get_current_timestamp()
+        end_timestamp = current_timestamp + self.timeout
         try:
             f = self.session.send_rpc(rpc_xml)
-            r = f.result(timeout=self.timeout)
-            if not r:
-                self._log_rpc_failure("RPC returned without result")
-            else:
-                (raw, ele) = f.result(timeout=self.timeout)
-                self._log_rpc_response(raw)
+            while current_timestamp < end_timestamp:
+                timeout = end_timestamp - current_timestamp
+                try:
+                    r = f.result(timeout=timeout)
+                    if not r:
+                        self._log_rpc_failure("RPC returned without result")
+                    else:
+                        (raw, ele) = f.result(timeout=timeout)
+                        self._log_rpc_response(raw)
+                    return (raw, ele)
+                except TimeoutError:
+                    current_timestamp = _get_current_timestamp()
+                    if current_timestamp >= end_timestamp:
+                        raise
         except CancelledError:
             self._log_rpc_failure("RPC cancelled")
             raise
@@ -229,8 +250,6 @@ class Manager:
             self._log_rpc_failure("RPC exception: {}".format(message))
             raise
 
-        return (raw, ele)
-
     def edit_config(
         self,
         config,
